Struct rfsapi::RawFileData
[−]
[src]
pub struct RawFileData {
pub mime_type: Mime,
pub name: String,
pub last_modified: Tm,
pub size: u64,
pub is_file: bool,
}Information about a file available through RFSAPI.
Fields
mime_type: Mime
File's determined MIME type.
Always valid, but possibly garbage for directories.
Recommended value for directories: "text/directory".
name: String
File's name, which can be used to navigate to it.
last_modified: Tm
File's last modification time, as returned by the FS.
size: u64
File size in bytes.
Possibly garbage for directories.
Recommended value for directories: 0.
is_file: bool
Whether the file is a file.